@@ -33,7 +33,7 @@ echo "Test 123 Conf" >/var/lib/univention-appcenter/apps/%(app_name)s/conf/test1
         appcenter.update()
 
         app.install()
-        app.verify(joined=False)
+        app.verify()
 
         lo = get_ldap_connection()
         print(lo.searchDn(filter=f'(&(cn={app.app_name[:5]}-*)(objectClass=univentionMemberServer)(!(aRecord=*))(!(macAddress=*)))', unique=True, required=True))
