@@ -1,9 +1,10 @@
-# SPDX-FileCopyrightText: 2013-2025 Univention GmbH
+# SPDX-FileCopyrightText: 2013-2026 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
 """Common functions used by tests."""
 
 
+import contextlib
 import functools
 import os
 import socket
@@ -320,6 +321,27 @@ def restart_listener() -> None:
     subprocess.call(('systemctl', 'restart', 'univention-directory-listener'))
 
 
+def stop_adconnector() -> None:
+    subprocess.check_call(['systemctl', 'stop', 'univention-ad-connector'])
+
+
+def start_adconnector() -> None:
+    subprocess.check_call(['systemctl', 'start', 'univention-ad-connector'])
+
+
+def restart_adconnector() -> None:
+    subprocess.check_call(['systemctl', 'restart', 'univention-ad-connector'])
+
+
+@contextlib.contextmanager
+def adconnector_stopped():
+    try:
+        stop_adconnector()
+        yield
+    finally:
+        start_adconnector()
+
+
 def restart_firewall() -> None:
     subprocess.call((FIREWALL_INIT_SCRIPT, 'restart'))
 
